Index: trunk/src/defs/class_id.h
===================================================================
--- trunk/src/defs/class_id.h	(revision 7391)
+++ trunk/src/defs/class_id.h	(revision 7393)
@@ -132,4 +132,5 @@
   CL_GAME_WORLD                 =    0x00101000,
   CL_GAME_WORLD_DATA            =    0x00102000,
+  CL_GAME_RULES                 =    0x00104000,
 
   CL_CAMPAIGN                   =    0x00000101,
@@ -142,8 +143,9 @@
   CL_MULTI_PLAYER_WORLD_DATA    =    0x00000108,
   CL_MOVIE_LOADER               =    0x00000109,
-  CL_GAME_RULES                 =    0x00000110,          ///HACK: this is no story entity, bensch: to rebuild
-  CL_MULTIPLAYER_TEAM_DEATHMATCH=    0x00000111,          ///HACK: this is no story entity: it is a CL_GAME_RULES, bensch: to rebuild
-  CL_SINGLEPLAYER_SHOOTEMUP     =    0x00000112,          ///HACK: this is no story entity: it is a CL_GAME_RULES, bensch: to rebuild
-  CL_MISSION_GOAL               =    0x00000113,          ///HACK: this is no story entity: it is a CL_BASE_OBJECT, bensch: to rebuild
+
+  CL_MULTIPLAYER_TEAM_DEATHMATCH=    0x00000111,
+  CL_SINGLEPLAYER_SHOOTEMUP     =    0x00000112,
+
+  CL_MISSION_GOAL               =    0x00000113,
 
   /// SUPER-PNodes
Index: trunk/src/lib/shell/shell_completion.h
===================================================================
--- trunk/src/lib/shell/shell_completion.h	(revision 7391)
+++ trunk/src/lib/shell/shell_completion.h	(revision 7393)
@@ -48,8 +48,9 @@
     bool objectComplete(const std::string& objectBegin, long classID);
     //  bool objectMatch(const char* objectBegin, long classID, unsigned int* length);
-    bool functionComplete(const std::string& functionBegin, const std::string& className);
+    bool commandComplete(const std::string& commandBegin, const std::string& className);
     //  bool functionMatch(const char* functionBegin, long classID, unsigned int* length);
     bool aliasComplete(const std::string& aliasBegin);
 
+    // Generally Completes.
     bool generalComplete(std::string& input,
                          const std::string& begin, const std::string& displayAs = "%s",
@@ -60,7 +61,7 @@
     bool addToCompleteList(const std::list<BaseObject*>& inputList, const std::string& completionBegin, ShellCompletion::CompletionType type);
 
-    void clearCompletionList();
 
     // Helpers.
+    void clearCompletionList();
     static const std::string& ShellCompletion::typeToString(ShellCompletion::CompletionType type);
 
Index: trunk/src/lib/shell/shell_input.h
===================================================================
--- trunk/src/lib/shell/shell_input.h	(revision 7391)
+++ trunk/src/lib/shell/shell_input.h	(revision 7393)
@@ -45,4 +45,5 @@
     void removeCharacters(unsigned int characterCount = 1);
     void setRepeatDelay(float repeatDelay, float repeatRate);
+
     bool executeCommand();
 

Index: trunk/src/lib/shell/shell_completion.cc
===================================================================
--- trunk/src/lib/shell/shell_completion.cc	(revision 7391)
+++ trunk/src/lib/shell/shell_completion.cc	(revision 7393)
@@ -112,5 +112,5 @@
       this->objectComplete(completeString, classID);
     if (completeType & FunctionCompletion)
-      this->functionComplete(completeString, inputSplits.getString(0));
+      this->commandComplete(completeString, inputSplits.getString(0));
     if (completeType & AliasCompletion)
       this->aliasComplete(completeString);
@@ -144,14 +144,14 @@
 
   /**
    * @brief completes a Function
    * @param functionBegin the beginning of the function String
    * @param classID the class' ID to complete the function of
    */
-  bool ShellCompletion::functionComplete(const std::string& functionBegin, const std::string& className)
+  bool ShellCompletion::commandComplete(const std::string& commandBegin, const std::string& className)
   {
     std::list<std::string> fktList;
     ShellCommandClass::getCommandListOfClass(className, fktList);
     //printf("%s\n", boList->firstElement()->getName());
-    if (!this->addToCompleteList(fktList, functionBegin, FunctionCompletion))
+    if (!this->addToCompleteList(fktList, commandBegin, FunctionCompletion))
       return false;
     return true;
@@ -144,14 +144,14 @@
 
   /**
-   * @brief completes a Function
-   * @param functionBegin the beginning of the function String
+   * @brief completes a Command
+   * @param commandBegin the beginning of the function String
    * @param classID the class' ID to complete the function of
    */